@@ -143,10 +143,11 @@ def _archive_read_next_header2(archive, entry):
     return r
 
 def _archive_read_disk_descend(archive):
-    try:
-        return libarchive.calls.archive_read.c_archive_read_disk_descend(
+    result = libarchive.calls.archive_read.c_archive_read_disk_descend(
                 archive)
-    except:
+
+    if result not in (libarchive.constants.archive.ARCHIVE_OK,
+                      libarchive.constants.archive.ARCHIVE_WARN):
         message = c_archive_error_string(archive)
         raise libarchive.exception.ArchiveError(message)
 
@@ -386,3 +387,4 @@ def memory_pour(buffer_, *args, **kwargs):
         _archive_read_open_memory(archive_res, buffer_)
 
     return _pour(opener, *args, flags=0, **kwargs)
+
