@@ -76,7 +76,7 @@ c_archive_read_next_header2.restype = c_int
 
 c_archive_read_disk_descend = libarchive.archive_read_disk_descend
 c_archive_read_disk_descend.argtypes = [c_void_p]
-c_archive_read_disk_descend.restype = _check_zero_success
+c_archive_read_disk_descend.restype = c_int
 
 c_archive_read_close = libarchive.archive_read_close
 c_archive_read_close.argtypes = [c_void_p]
